{% extends BASE_TEMPLATE %}

{% load staticfiles %}

{% block head-title %}Settings{% endblock %}

{% block title %}
<link rel="stylesheet" type="text/css" href="{% static 'bom/style.css' %}" />
{% endblock %}

{% block menu %}
{% endblock%}

{% block content %}
<h1>Settings</h1>
<h2>Octopart</h2>
<p>Select Octopart sources to sync.</p>
{% endblock %}